@@ -1,7 +1,7 @@
 /*
  * frogr-about-dialog.c -- About dialog
  *
- * Copyright (C) 2009-2014 Mario Sanchez Prada
+ * Copyright (C) 2009-2017 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 #include <glib/gi18n.h>
 
 /* Path relative to the icons dir */
-#define ABOUT_DIALOG_ICON "/hicolor/48x48/apps/frogr.png"
+#define ABOUT_DIALOG_ICON "/hicolor/48x48/apps/" APP_ID ".png"
 
 static const gchar *authors[] = {
   "Mario Sanchez Prada <msanchez@gnome.org>",
@@ -41,26 +41,24 @@ static const gchar *artists[] = {
 };
 
 static const gchar *appdescr = N_("A Flickr Remote Organizer for GNOME\n");
-static const gchar *copyright = "(c) 2009-2015 Mario Sanchez Prada";
+static const gchar *copyright = "(c) 2009-2017 Mario Sanchez Prada";
 static const gchar *website = "http://wiki.gnome.org/Apps/Frogr";
 
 void
 frogr_about_dialog_show (GtkWindow *parent)
 {
-  GdkPixbuf *logo = NULL;
-  gchar *version = NULL;
-  gchar *icon_full_path = NULL;
+  g_autoptr(GdkPixbuf) logo = NULL;
+  g_autofree gchar *version = NULL;
+  g_autofree gchar *icon_full_path = NULL;
 
   icon_full_path = g_strdup_printf ("%s/" ABOUT_DIALOG_ICON,
 				    frogr_util_get_icons_dir ());
   logo = gdk_pixbuf_new_from_file (icon_full_path, NULL);
-  g_free (icon_full_path);
-
-  version = g_strdup_printf ("%s", VERSION);
+  version = g_strdup_printf ("%s", PACKAGE_VERSION);
 
   /* Show about dialog */
   gtk_show_about_dialog (GTK_WINDOW (parent),
-                         "name", PACKAGE,
+                         "name", PACKAGE_NAME,
                          "authors", authors,
                          "artists", artists,
                          "comments", _(appdescr),
@@ -72,7 +70,4 @@ frogr_about_dialog_show (GtkWindow *parent)
                          "translator-credits", _("translator-credits"),
                          "modal", TRUE,
                          NULL);
-
-  g_object_unref (logo);
-  g_free (version);
 }
