@@ -226,8 +226,8 @@ _tree_iter_compare_n_elements_func (GtkTreeModel *model,
                                     GtkTreeIter *b,
                                     gpointer data)
 {
-  gchar *a_str = NULL;
-  gchar *b_str = NULL;
+  g_autofree gchar *a_str = NULL;
+  g_autofree gchar *b_str = NULL;
   gint a_value = 0;
   gint b_value = 0;
 
@@ -239,9 +239,6 @@ _tree_iter_compare_n_elements_func (GtkTreeModel *model,
   a_value = g_ascii_strtoll (a_str, NULL, 10);
   b_value = g_ascii_strtoll (b_str, NULL, 10);
 
-  g_free (a_str);
-  g_free (b_str);
-
   return (a_value - b_value);
 }
 
@@ -290,7 +287,7 @@ _fill_dialog_with_data (FrogrAddToSetDialog *self)
   gtk_tree_model_get_iter_first (self->treemodel, &iter);
   do
     {
-      FrogrPhotoSet *set = NULL;
+      g_autoptr(FrogrPhotoSet) set = NULL;
       GSList *p_item = NULL;
       gboolean do_check = TRUE;
 
@@ -308,7 +305,6 @@ _fill_dialog_with_data (FrogrAddToSetDialog *self)
               break;
             }
         }
-      g_object_unref (set);
 
       gtk_list_store_set (GTK_LIST_STORE (self->treemodel), &iter,
                           CHECKBOX_COL, do_check, -1);
@@ -464,15 +460,13 @@ _frogr_add_to_set_dialog_dispose (GObject *object)
 
   if (dialog->pictures)
     {
-      g_slist_foreach (dialog->pictures, (GFunc)g_object_unref, NULL);
-      g_slist_free (dialog->pictures);
+      g_slist_free_full (dialog->pictures, g_object_unref);
       dialog->pictures = NULL;
     }
 
    if (dialog->photosets)
     {
-      g_slist_foreach (dialog->photosets, (GFunc)g_object_unref, NULL);
-      g_slist_free (dialog->photosets);
+      g_slist_free_full (dialog->photosets, g_object_unref);
       dialog->photosets = NULL;
     }
 
