@@ -1,7 +1,7 @@
 /*
  * frogr-main-view.c -- Main view for the application
  *
- * Copyright (C) 2009-2015 Mario Sanchez Prada
+ * Copyright (C) 2009-2017 Mario Sanchez Prada
  *           (C) 2011 Joaquim Rocha
  * Authors:
  *   Joaquim Rocha <jrocha@igalia.com>
@@ -37,7 +37,7 @@
 #include <glib/gi18n.h>
 
 /* Paths relative to the icons dir */
-#define ICON_PATH_FORMAT_STRING "%s/hicolor/%s/apps/frogr.png"
+#define ICON_PATH_FORMAT_STRING "%s/hicolor/%s/apps/" APP_ID ".png"
 
 #define MENU_BUTTON_ICON "open-menu-symbolic"
 #define MENU_BUTTON_ICON_FALLBACK "emblem-system-symbolic"
@@ -46,13 +46,13 @@
 #define MINIMUM_WINDOW_HEIGHT 600
 
 /* Path relative to the application data dir */
-#define UI_MAIN_VIEW_FILE "/gtkbuilder/frogr-main-view.xml"
-#define UI_APP_MENU_FILE "/gtkbuilder/frogr-app-menu.xml"
-#define UI_CONTEXT_MENU_FILE "/gtkbuilder/frogr-context-menu.xml"
+#define UI_MAIN_VIEW_FILE "/gtkbuilder/frogr-main-view.ui"
+#define UI_APP_MENU_FILE "/gtkbuilder/frogr-app-menu.ui"
+#define UI_CONTEXT_MENU_FILE "/gtkbuilder/frogr-context-menu.ui"
 #if USE_HEADER_BAR
-#define UI_MENU_BUTTON_FILE "/gtkbuilder/frogr-menu-button.xml"
+#define UI_MENU_BUTTON_FILE "/gtkbuilder/frogr-menu-button.ui"
 #else
-#define UI_MENU_BAR_FILE "/gtkbuilder/frogr-menu-bar.xml"
+#define UI_MENU_BAR_FILE "/gtkbuilder/frogr-menu-bar.ui"
 #endif
 
 /* Action names for menu items */
@@ -82,14 +82,6 @@
 #define ACTION_SORT_IN_REVERSE_ORDER "sort-in-reverse-order"
 #define ACTION_ENABLE_TOOLTIPS "enable-tooltips"
 
-/* This should map to Control in X11 and to Command in OS X */
-#ifdef PLATFORM_MAC
-#define GDK_PRIMARY_MASK GDK_MOD2_MASK
-#else
-#define GDK_PRIMARY_MASK GDK_CONTROL_MASK
-#endif
-
-
 struct _FrogrMainView {
   GtkApplicationWindow parent;
 
@@ -151,7 +143,6 @@ typedef enum {
 /* Prototypes */
 
 static void _initialize_ui (FrogrMainView *self);
-static gboolean _initialize_app_menu (FrogrMainView *self);
 
 #if USE_HEADER_BAR
 static void _initialize_header_bar (FrogrMainView *self);
@@ -173,10 +164,6 @@ static void _on_toggle_menu_item_changed (GSimpleAction *action, GVariant *param
 
 static void _quit_application (FrogrMainView *self);
 
-#ifdef PLATFORM_MAC
-static void _tweak_app_menu_for_mac (FrogrMainView *self);
-#endif
-
 static void _populate_accounts_submenu (FrogrMainView *self);
 
 static void _initialize_drag_n_drop (FrogrMainView *self);
@@ -358,8 +345,7 @@ _initialize_ui (FrogrMainView *self)
     }
 
   gtk_window_set_default_icon_list (icons);
-  g_list_foreach (icons, (GFunc) g_object_unref, NULL);
-  g_list_free (icons);
+  g_list_free_full (icons, g_object_unref);
 
   /* Get widgets from GtkBuilder */
   builder = gtk_builder_new ();
@@ -517,28 +503,9 @@ _initialize_ui (FrogrMainView *self)
   /* Show the auth dialog, if needed, on idle */
   gdk_threads_add_idle ((GSourceFunc) _maybe_show_auth_dialog_on_idle, self);
 
-#ifdef PLATFORM_MAC
-  /* FIXME: This is an UGLY hack that helps avoiding the race condition
-     but probably does not prevent it completely. Needs to check it more
-     carefully and fix it properly in the future when I have more time. */
-  gdk_threads_add_timeout (1000, (GSourceFunc) _initialize_app_menu, self);
-#else
-  _initialize_app_menu (self);
-#endif
-
-  gtk_widget_show (GTK_WIDGET (self));
-}
-
-static gboolean
-_initialize_app_menu (FrogrMainView *self)
-{
   _populate_accounts_submenu (self);
 
-#ifdef PLATFORM_MAC
-  _tweak_app_menu_for_mac (self);
-#endif
-
-  return FALSE;
+  gtk_widget_show (GTK_WIDGET (self));
 }
 
 #if USE_HEADER_BAR
@@ -617,7 +584,7 @@ static void _initialize_header_bar (FrogrMainView *self)
   GtkWidget *menu = NULL;
   GtkWidget *menu_image = NULL;
   GtkIconTheme *icon_theme = NULL;
-  gchar *full_path = NULL;
+  g_autofree gchar *full_path = NULL;
 
   self->header_bar = gtk_header_bar_new ();
 
@@ -636,7 +603,6 @@ static void _initialize_header_bar (FrogrMainView *self)
 
   full_path = g_strdup_printf ("%s/" UI_MENU_BUTTON_FILE, frogr_util_get_app_data_dir ());
   gtk_builder_add_from_file (self->builder, full_path, NULL);
-  g_free (full_path);
 
   menu_model = G_MENU_MODEL (gtk_builder_get_object (self->builder, "menu-button"));
   extract_accels_from_menu (menu_model, self->gtk_app);
@@ -703,13 +669,12 @@ static void _initialize_menubar_and_toolbar (FrogrMainView *self)
 {
   GtkWidget *toolbar = NULL;
   GtkToolItem *toolbar_items[7];
-  gchar *full_path = NULL;
+  g_autofree gchar *full_path = NULL;
   gint i;
 
   /* Menu bar */
   full_path = g_strdup_printf ("%s/" UI_MENU_BAR_FILE, frogr_util_get_app_data_dir ());
   gtk_builder_add_from_file (self->builder, full_path, NULL);
-  g_free (full_path);
 
   g_action_map_add_action_entries (G_ACTION_MAP (self),
                                    win_entries, G_N_ELEMENTS (win_entries),
@@ -787,9 +752,9 @@ _update_project_path (FrogrMainView *self, const gchar *path)
     }
   else
     {
-      GFile *file = NULL;
-      GFile *dir = NULL;
-      GFileInfo *file_info = NULL;
+      g_autoptr(GFile) file = NULL;
+      g_autoptr(GFile) dir = NULL;
+      g_autoptr(GFileInfo) file_info = NULL;
       gchar *dir_path = NULL;
       const gchar *home_dir = NULL;
 
@@ -808,19 +773,15 @@ _update_project_path (FrogrMainView *self, const gchar *path)
       home_dir = g_get_home_dir ();
       if (g_str_has_prefix (dir_path, home_dir))
         {
-          gchar *tmp_path = NULL;
+          g_autofree gchar *tmp_path = NULL;
 
           tmp_path = dir_path;
           dir_path = g_strdup_printf ("~%s", &dir_path[g_utf8_strlen (home_dir, -1)]);
-          g_free (tmp_path);
         }
       self->project_dir = dir_path;
 
       /* Finally, store the raw path too */
       self->project_filepath = g_strdup (path);
-
-      g_object_unref (file);
-      g_object_unref (dir);
     }
 }
 
@@ -828,8 +789,8 @@ static void
 _update_window_title (FrogrMainView *self, gboolean dirty)
 {
 #if USE_HEADER_BAR
-  gchar *title = NULL;
-  gchar *subtitle = NULL;
+  g_autofree gchar *title = NULL;
+  g_autofree gchar *subtitle = NULL;
 
   title = self->project_name
     ? g_strdup_printf ("%s%s", (dirty ? "*" : ""), self->project_name)
@@ -842,13 +803,10 @@ _update_window_title (FrogrMainView *self, gboolean dirty)
   gtk_header_bar_set_title (GTK_HEADER_BAR (self->header_bar), title);
   gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self->header_bar), subtitle);
 
-  g_free (subtitle);
-  g_free (title);
-
 #else /* !USE_HEADER_BAR */
 
-  gchar *session_string = NULL;
-  gchar *window_title = NULL;
+  g_autofree gchar *session_string = NULL;
+  g_autofree gchar *window_title = NULL;
 
   session_string = self->project_name
     ? g_strdup_printf ("%s%s (%s) - ", (dirty ? "*" : ""),
@@ -856,10 +814,7 @@ _update_window_title (FrogrMainView *self, gboolean dirty)
     : g_strdup("");
 
   window_title = g_strdup_printf ("%s%s", session_string, APP_SHORTNAME);
-  g_free (session_string);
-
   gtk_window_set_title (GTK_WINDOW (self), window_title);
-  g_free (window_title);
 #endif
 }
 
@@ -1001,27 +956,6 @@ _quit_application (FrogrMainView *self)
   g_application_quit (G_APPLICATION (self->gtk_app));
 }
 
-#ifdef PLATFORM_MAC
-static void
-_tweak_app_menu_for_mac (FrogrMainView *self)
-{
-  GMenuModel *menu = NULL;
-
-  /* Hide the Section including the 'Help' menu item */
-  g_menu_remove (G_MENU (self->app_menu), 2);
-
-  /* The section removed contained the 'About' and 'Quit' items, so
-     create new ones and place them in their right places */
-  menu = G_MENU_MODEL (g_menu_new ());
-  g_menu_append_item (G_MENU (menu), g_menu_item_new (_("_About"), "app.about"));
-  g_menu_insert_section (G_MENU (self->app_menu), 0, NULL, menu);
-
-  menu = G_MENU_MODEL (g_menu_new ());
-  g_menu_append_item (G_MENU (menu), g_menu_item_new (_("_Quit"), "app.quit"));
-  g_menu_insert_section (G_MENU (self->app_menu), 3, NULL, menu);
-}
-#endif
-
 static void
 _populate_accounts_submenu (FrogrMainView *self)
 {
@@ -1094,7 +1028,7 @@ _on_icon_view_drag_data_received (GtkWidget *widget,
   FrogrMainView *self = NULL;
   GdkAtom target;
   GSList *fileuris_list = NULL;
-  gchar **fileuris_array = NULL;
+  g_auto(GStrv) fileuris_array = NULL;
   gint i;
 
   self = FROGR_MAIN_VIEW (data);
@@ -1120,9 +1054,6 @@ _on_icon_view_drag_data_received (GtkWidget *widget,
 
   /* Finish drag and drop */
   gtk_drag_finish (context, TRUE, FALSE, time);
-
-  /* Free */
-  g_strfreev (fileuris_array);
 }
 
 gboolean
@@ -1149,8 +1080,17 @@ _on_icon_view_key_press_event (GtkWidget *widget,
       && self->n_selected_pictures > 0)
     {
       GtkMenu *menu = GTK_MENU (self->pictures_ctxt_menu);
+
+#if GTK_CHECK_VERSION (3, 22, 0)
+      gtk_menu_popup_at_widget (menu,
+                                widget,
+                                GDK_GRAVITY_CENTER,
+                                GDK_GRAVITY_CENTER,
+                                (GdkEvent *) event);
+#else
       gtk_menu_popup (menu, NULL, NULL, NULL, NULL,
                       0, gtk_get_current_event_time ());
+#endif
     }
 
   return FALSE;
@@ -1179,7 +1119,7 @@ _handle_selection_for_button_event_and_path (FrogrMainView *self,
                                              GdkEventButton *event,
                                              GtkTreePath *path)
 {
-  gboolean using_primary_key = event->state & GDK_PRIMARY_MASK;
+  gboolean using_primary_key = event->state & GDK_CONTROL_MASK;
   gboolean using_shift_key = event->state & GDK_SHIFT_MASK;
   gboolean is_single_click = event->type == GDK_BUTTON_PRESS;
   gboolean is_double_click = event->type == GDK_2BUTTON_PRESS;
@@ -1286,7 +1226,7 @@ _on_icon_view_button_press_event (GtkWidget *widget,
                                   gpointer data)
 {
   FrogrMainView *self = FROGR_MAIN_VIEW (data);
-  gboolean using_primary_key = event->state & GDK_PRIMARY_MASK;
+  gboolean using_primary_key = event->state & GDK_CONTROL_MASK;
   gboolean using_shift_key = event->state & GDK_SHIFT_MASK;
   GtkTreePath *new_path = NULL;
 
@@ -1325,10 +1265,15 @@ _on_icon_view_button_press_event (GtkWidget *widget,
       else if (!is_primary_btn && is_single_click)
         {
           /* Show contextual menu */
+#if GTK_CHECK_VERSION (3, 22, 0)
+          gtk_menu_popup_at_pointer (GTK_MENU (self->pictures_ctxt_menu),
+                                     (GdkEvent *) event);
+#else
           gtk_menu_popup (GTK_MENU (self->pictures_ctxt_menu),
               NULL, NULL, NULL, NULL,
               event->button,
               gtk_get_current_event_time ());
+#endif
         }
 
       /* Free */
@@ -1379,13 +1324,13 @@ _on_icon_view_query_tooltip (GtkWidget *icon_view,
                                                      x, y, &bw_x, &bw_y);
   if (gtk_icon_view_get_item_at_pos (GTK_ICON_VIEW (icon_view), bw_x, bw_y, &path, NULL))
     {
-      FrogrPicture *picture;
+      g_autoptr(FrogrPicture) picture = NULL;
       GtkTreeIter iter;
-      gchar *tooltip_str = NULL;
-      gchar *filesize = NULL;
-      gchar *filesize_str = NULL;
-      gchar *filesize_markup = NULL;
-      gchar *datetime_markup = NULL;
+      g_autofree gchar *tooltip_str = NULL;
+      g_autofree gchar *filesize = NULL;
+      g_autofree gchar *filesize_str = NULL;
+      g_autofree gchar *filesize_markup = NULL;
+      g_autofree gchar *datetime_markup = NULL;
       const gchar *datetime = NULL;
 
       /* Get needed information */
@@ -1404,12 +1349,11 @@ _on_icon_view_query_tooltip (GtkWidget *icon_view,
       datetime = frogr_picture_get_datetime (picture);
       if (datetime)
         {
-          gchar *datetime_str = NULL;
+          g_autofree gchar *datetime_str = NULL;
 
           /* String showind the date and time a picture was taken */
           datetime_str = g_strdup_printf (_("Taken: %s"), datetime);
           datetime_markup = g_strdup_printf ("\n<i>%s</i>", datetime_str);
-          g_free (datetime_str);
         }
 
       filesize_str = g_strdup_printf (_("File size: %s"), filesize);
@@ -1424,12 +1368,6 @@ _on_icon_view_query_tooltip (GtkWidget *icon_view,
 
       /* Free memory */
       gtk_tree_path_free (path);
-      g_object_unref (picture);
-      g_free (tooltip_str);
-      g_free (filesize);
-      g_free (filesize_str);
-      g_free (filesize_markup);
-      g_free (datetime_markup);
       return TRUE;
     }
 
@@ -1449,9 +1387,7 @@ _on_icon_view_selection_changed (GtkWidget *icon_view, gpointer data)
     gtk_icon_view_get_selected_items (GTK_ICON_VIEW (self->icon_view));
 
   len = g_list_length (selected_pictures);
-
-  g_list_foreach (selected_pictures, (GFunc)gtk_tree_path_free, NULL);
-  g_list_free (selected_pictures);
+  g_list_free_full (selected_pictures, (GDestroyNotify)gtk_tree_path_free);
 
   self->n_selected_pictures = len;
 
@@ -1516,7 +1452,7 @@ _open_project_dialog_response_cb (GtkDialog *dialog,
 
   if (response == GTK_RESPONSE_ACCEPT)
     {
-      gchar *filename = NULL;
+      g_autofree gchar *filename = NULL;
 
       filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
       if (filename != NULL)
@@ -1524,7 +1460,6 @@ _open_project_dialog_response_cb (GtkDialog *dialog,
           /* Load from disk and update project's path */
           if (frogr_controller_open_project_from_file (self->controller, filename))
             _update_window_title (self, FALSE);
-          g_free (filename);
         }
     }
 
@@ -1586,21 +1521,19 @@ _save_project_as_dialog_response_cb (GtkDialog *dialog, gint response, gpointer
 
   if (response == GTK_RESPONSE_ACCEPT)
     {
-      gchar *filename = NULL;
+      g_autofree gchar *filename = NULL;
 
       filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
       if (filename != NULL)
         {
-          gchar *actual_filename = NULL;
+          g_autofree gchar *actual_filename = NULL;
 
           /* Add the '.frogr' extension if not present */
           actual_filename = g_str_has_suffix (filename, ".frogr")
             ? g_strdup (filename)
             : g_strdup_printf ("%s.frogr", filename);
-          g_free (filename);
 
           _save_project_to_file (self, actual_filename);
-          g_free (actual_filename);
         }
     }
 
@@ -1657,7 +1590,7 @@ _load_pictures_dialog (FrogrMainView *self)
   GtkWidget *dialog;
   GtkFileFilter *all_filter;
   GtkFileFilter *image_filter;
-#ifdef HAVE_GSTREAMER
+#if HAVE_GSTREAMER
   GtkFileFilter *video_filter;
 #endif
   gint i;
@@ -1674,7 +1607,7 @@ _load_pictures_dialog (FrogrMainView *self)
   /* Set images filter */
   all_filter = gtk_file_filter_new ();
   image_filter = gtk_file_filter_new ();
-#ifdef HAVE_GSTREAMER
+#if HAVE_GSTREAMER
   video_filter = gtk_file_filter_new ();
 #endif
 
@@ -1683,7 +1616,7 @@ _load_pictures_dialog (FrogrMainView *self)
     {
       if (g_str_has_prefix (supported_mimetypes[i], "image"))
         gtk_file_filter_add_mime_type (image_filter, supported_mimetypes[i]);
-#ifdef HAVE_GSTREAMER
+#if HAVE_GSTREAMER
       else
         gtk_file_filter_add_mime_type (video_filter, supported_mimetypes[i]);
 #endif
@@ -1697,7 +1630,7 @@ _load_pictures_dialog (FrogrMainView *self)
   gtk_file_filter_set_name (image_filter, _("Image Files"));
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), image_filter);
 
-#ifdef HAVE_GSTREAMER
+#if HAVE_GSTREAMER
   gtk_file_filter_set_name (video_filter, _("Video Files"));
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), video_filter);
 #endif
@@ -1805,8 +1738,7 @@ _open_pictures_in_external_viewer (FrogrMainView *self)
 
   pictures = _get_selected_pictures (self);
   frogr_util_open_pictures_in_viewer (pictures);
-  g_slist_foreach (pictures, (GFunc)g_object_unref, NULL);
-  g_slist_free (pictures);
+  g_slist_free_full (pictures, g_object_unref);
 }
 
 static void
@@ -1830,8 +1762,7 @@ _remove_selected_pictures (FrogrMainView *self)
   _update_ui (self);
 
   /* Free */
-  g_slist_foreach (selected_pictures, (GFunc)g_object_unref, NULL);
-  g_slist_free (selected_pictures);
+  g_slist_free_full (selected_pictures, g_object_unref);
 }
 
 static void
@@ -1854,14 +1785,13 @@ static void
 _reorder_pictures (FrogrMainView *self, SortingCriteria criteria, gboolean reversed)
 {
   GSList *list_as_loaded = NULL;
-  GSList *current_list = NULL;
   GSList *current_item = NULL;
-  gint *new_order = 0;
+  g_autoptr(GSList) current_list = NULL;
+  g_autofree gchar *property_name = NULL;
+  g_autofree gint *new_order = 0;
   gint current_pos = 0;
   gint new_pos = 0;
 
-  gchar *property_name = NULL;
-
   self->sorting_criteria = criteria;
   self->sorting_reversed = reversed;
 
@@ -1904,10 +1834,7 @@ _reorder_pictures (FrogrMainView *self, SortingCriteria criteria, gboolean rever
                                              (gchar*)property_name);
   /* Update the list of pictures */
   if (self->sorted_pictures)
-    {
-      g_slist_foreach (self->sorted_pictures, (GFunc)g_object_unref, NULL);
-      g_slist_free (self->sorted_pictures);
-    }
+    g_slist_free_full (self->sorted_pictures, g_object_unref);
   self->sorted_pictures = list_as_loaded;
   g_slist_foreach (self->sorted_pictures, (GFunc)g_object_ref, NULL);
 
@@ -1923,10 +1850,6 @@ _reorder_pictures (FrogrMainView *self, SortingCriteria criteria, gboolean rever
       new_order[new_pos] = current_pos++;
     }
   gtk_list_store_reorder (GTK_LIST_STORE (self->tree_model), new_order);
-
-  g_slist_free (current_list);
-  g_free (new_order);
-  g_free (property_name);
 }
 
 static void
@@ -2036,7 +1959,7 @@ _model_picture_removed (FrogrController *controller,
       gboolean found = FALSE;
       do
         {
-          FrogrPicture *picture_from_ui;
+          g_autoptr(FrogrPicture) picture_from_ui = NULL;
 
           /* Get needed information */
           gtk_tree_model_get (self->tree_model,
@@ -2055,7 +1978,6 @@ _model_picture_removed (FrogrController *controller,
 
               found = TRUE;
             }
-          g_object_unref (picture_from_ui);
         }
       while (!found && gtk_tree_model_iter_next (tree_model, &iter));
     }
@@ -2097,9 +2019,9 @@ _craft_state_description (FrogrMainView *self)
   guint n_pictures = 0;
   const gchar *login = NULL;
   gchar *description = NULL;
-  gchar *login_str = NULL;
-  gchar *bandwidth_str = NULL;
-  gchar *upload_size_str = NULL;
+  g_autofree gchar *login_str = NULL;
+  g_autofree gchar *bandwidth_str = NULL;
+  g_autofree gchar *upload_size_str = NULL;
   gboolean is_pro = FALSE;
 
   account = frogr_controller_get_active_account (self->controller);
@@ -2122,8 +2044,8 @@ _craft_state_description (FrogrMainView *self)
      permanently show that they have 2.0 GB / 2.0 GB remaining */
   if (!is_pro)
     {
-      gchar *remaining_bw_str = NULL;
-      gchar *max_bw_str = NULL;
+      g_autofree gchar *remaining_bw_str = NULL;
+      g_autofree gchar *max_bw_str = NULL;
       gulong remaining_bw;
       gulong max_bw;
 
@@ -2144,9 +2066,6 @@ _craft_state_description (FrogrMainView *self)
                                            remaining_bw_str,
                                            max_bw_str);
         }
-
-      g_free (remaining_bw_str);
-      g_free (max_bw_str);
     }
 
   /* Check size of the loaded pictures, if any */
@@ -2156,7 +2075,7 @@ _craft_state_description (FrogrMainView *self)
     {
       GSList *item = NULL;
       gulong total_size = 0;
-      gchar *total_size_str = NULL;
+      g_autofree gchar *total_size_str = NULL;
 
       for (item = pictures; item; item = g_slist_next (item))
         total_size += frogr_picture_get_filesize (FROGR_PICTURE (item->data));
@@ -2170,7 +2089,6 @@ _craft_state_description (FrogrMainView *self)
                                                    " - %d files to upload (%s)",
                                                    n_pictures),
                                          n_pictures, total_size_str);
-      g_free (total_size_str);
     }
 
   /* Build the final string */
@@ -2178,10 +2096,6 @@ _craft_state_description (FrogrMainView *self)
                                  login_str,
                                  (bandwidth_str ? bandwidth_str : ""),
                                  (upload_size_str ? upload_size_str : ""));
-  g_free (login_str);
-  g_free (bandwidth_str);
-  g_free (upload_size_str);
-
   return description;
 }
 
@@ -2218,7 +2132,7 @@ _update_sensitiveness (FrogrMainView *self)
   /* gboolean has_accounts = FALSE; */
   gboolean has_pics = FALSE;
   gint n_selected_pics = 0;
-  gchar **action_names = NULL;
+  g_auto(GStrv) action_names = NULL;
   gint i = 0;
 
   /* Set sensitiveness */
@@ -2230,7 +2144,6 @@ _update_sensitiveness (FrogrMainView *self)
       action_names = g_action_group_list_actions (G_ACTION_GROUP (self));
       for (i = 0; action_names[i]; i++)
         _update_sensitiveness_for_action (self, action_names[i], FALSE);
-      g_strfreev (action_names);
       break;
 
     case FROGR_STATE_IDLE:
@@ -2292,8 +2205,7 @@ _frogr_main_view_dispose (GObject *object)
 
   if (self->sorted_pictures)
     {
-      g_slist_foreach (self->sorted_pictures, (GFunc)g_object_unref, NULL);
-      g_slist_free (self->sorted_pictures);
+      g_slist_free_full (self->sorted_pictures, g_object_unref);
       self->sorted_pictures = NULL;
     }
 
