@@ -1,7 +1,7 @@
 /*
  * frogr-util.c -- Misc tools.
  *
- * Copyright (C) 2010-2016 Mario Sanchez Prada
+ * Copyright (C) 2010-2017 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -27,9 +27,9 @@
 #include <config.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#ifdef HAVE_GSTREAMER
+#if HAVE_GSTREAMER
 #include <gst/gst.h>
-#ifdef HAVE_GSTREAMER_1_0
+#if HAVE_GSTREAMER_1_0
 #include <gst/base/gstbasesink.h>
 #endif
 #endif
@@ -40,8 +40,8 @@
 #include <libexif/exif-loader.h>
 #include <libexif/exif-tag.h>
 
-#ifdef HAVE_GSTREAMER
-#ifdef HAVE_GSTREAMER_1_0
+#if HAVE_GSTREAMER
+#if HAVE_GSTREAMER_1_0
 #define CAPS "video/x-raw,format=RGB,width=160,pixel-aspect-ratio=1/1"
 #define PREROLL_TIMEOUT (5*GST_SECOND)
 #else
@@ -52,43 +52,24 @@
 static gboolean
 _spawn_command (const gchar* cmd)
 {
-  GError *error = NULL;
+  g_autoptr(GError) error = NULL;
 
   if (!g_spawn_command_line_async (cmd, &error))
     {
       if (error)
-        {
-          DEBUG ("Error spawning command '%s': %s", cmd, error->message);
-          g_error_free (error);
-        }
+        DEBUG ("Error spawning command '%s': %s", cmd, error->message);
 
       return FALSE;
     }
   return TRUE;
 }
 
-const gchar *
-_get_data_dir (void)
-{
-#ifdef PLATFORM_MAC
-  /* For MacOSX, we return the value of the environment value set by
-     the wrapper script running the application */
-  static gchar *xdg_data_dir = NULL;
-  if (!xdg_data_dir)
-    xdg_data_dir = g_strdup (g_getenv("XDG_DATA_DIRS"));
-  return (const gchar *) xdg_data_dir;
-#else
-  /* For GNOME, we just return DATA_DIR */
-  return DATA_DIR;
-#endif
-}
-
 const gchar *
 frogr_util_get_app_data_dir (void)
 {
   static gchar *app_data_dir = NULL;
   if (!app_data_dir)
-    app_data_dir = g_strdup_printf ("%s/frogr", _get_data_dir ());
+    app_data_dir = g_strdup_printf ("%s/frogr", DATADIR);
 
   return (const gchar *) app_data_dir;
 }
@@ -98,36 +79,16 @@ frogr_util_get_icons_dir (void)
 {
   static gchar *icons_dir = NULL;
   if (!icons_dir)
-    icons_dir = g_strdup_printf ("%s/icons", _get_data_dir ());
+    icons_dir = g_strdup_printf ("%s/icons", DATADIR);
 
   return (const gchar *) icons_dir;
 }
 
-const gchar *
-frogr_util_get_locale_dir (void)
-{
-  static const gchar *locale_dir = NULL;
-  if (!locale_dir)
-    {
-#ifndef PLATFORM_MAC
-      /* If not in MacOSX, we trust the defined variable better */
-      locale_dir = g_strdup (LOCALEDIR);
-#endif
-
-      /* Fallback for MacOSX and cases where FROGR_LOCALE_DIR was not
-	 defined yet because of any reason */
-      if (!locale_dir)
-	locale_dir = g_strdup_printf ("%s/locale", _get_data_dir ());
-    }
-
-  return (const gchar *) locale_dir;
-}
-
 gchar *
 _get_uris_string_from_list (GList *uris_list)
 {
   GList *current_uri = NULL;
-  gchar **uris_array = NULL;
+  g_auto(GStrv) uris_array = NULL;
   gchar *uris_str = NULL;
   gint n_uris = 0;
   gint i = 0;
@@ -138,10 +99,9 @@ _get_uris_string_from_list (GList *uris_list)
 
   uris_array = g_new0 (gchar*, n_uris + 1);
   for (current_uri = uris_list; current_uri; current_uri = g_list_next (current_uri))
-    uris_array[i++] = (gchar *) (current_uri->data);
+    uris_array[i++] = g_strdup (current_uri->data);
 
   uris_str = g_strjoinv (" ", uris_array);
-  g_free (uris_array);
 
   return uris_str;
 }
@@ -149,40 +109,27 @@ _get_uris_string_from_list (GList *uris_list)
 static void
 _open_uris_with_app_info (GList *uris_list, GAppInfo *app_info)
 {
-  GError *error = NULL;
+  g_autoptr(GError) error = NULL;
 
-  /* Early return */
-  if (!uris_list)
-    return;
+  g_return_if_fail (uris_list != NULL);
 
   if (!app_info || !g_app_info_launch_uris (app_info, uris_list, NULL, &error))
     {
-      /* The default app didn't succeed, so try 'xdg-open' / 'open' */
-      gchar *command = NULL;
-      gchar *uris = NULL;
+      /* The default app didn't succeed, so try 'gio open' */
+      g_autofree gchar *command = NULL;
+      g_autofree gchar *uris = NULL;
 
       uris = _get_uris_string_from_list (uris_list);
-
-#ifdef PLATFORM_MAC
-      /* In MacOSX use 'open' instead of 'xdg-open' */
-      command = g_strdup_printf ("open %s", uris);
+#if GLIB_CHECK_VERSION (2, 50, 0)
+      command = g_strdup_printf ("gio open %s", uris);
 #else
       command = g_strdup_printf ("gvfs-open %s", uris);
 #endif
       _spawn_command (command);
 
       if (error)
-        {
-          DEBUG ("Error opening URI(s) %s: %s", uris, error->message);
-          g_error_free (error);
-        }
-
-      g_free (command);
-      g_free (uris);
+        DEBUG ("Error opening URI(s) %s: %s", uris, error->message);
     }
-
-  g_list_foreach (uris_list, (GFunc) g_free, NULL);
-  g_list_free (uris_list);
 }
 
 void
@@ -191,11 +138,8 @@ frogr_util_open_uri (const gchar *uri)
   GAppInfo *app_info = NULL;
   GList *uris_list = NULL;
 
-  /* Early return */
-  if (!uri)
-    return;
+  g_return_if_fail (uri != NULL);
 
-#ifndef PLATFORM_MAC
   /* Supported network URIs */
   if (g_str_has_prefix (uri, "http:") || g_str_has_prefix (uri, "https:"))
     app_info = g_app_info_get_default_for_uri_scheme ("http");
@@ -203,10 +147,10 @@ frogr_util_open_uri (const gchar *uri)
   /* Supported help URIs */
   if (g_str_has_prefix (uri, "help:"))
     app_info = g_app_info_get_default_for_uri_scheme ("help");
-#endif
 
   uris_list = g_list_append (uris_list, g_strdup (uri));
   _open_uris_with_app_info (uris_list, app_info);
+  g_list_free_full (uris_list, g_free);
 }
 
 void
@@ -217,9 +161,7 @@ frogr_util_open_pictures_in_viewer (GSList *pictures)
   GSList *current_pic = NULL;
   FrogrPicture *picture = NULL;
 
-  /* Early return */
-  if (!pictures)
-    return;
+  g_return_if_fail (pictures != NULL);
 
   for (current_pic = pictures; current_pic; current_pic = g_slist_next (current_pic))
     {
@@ -237,6 +179,7 @@ frogr_util_open_pictures_in_viewer (GSList *pictures)
 
   /* uris_list will be freed inside of the function */
   _open_uris_with_app_info (uris_list, app_info);
+  g_list_free_full (uris_list, g_free);
 }
 
 static void
@@ -344,9 +287,9 @@ _get_corrected_pixbuf (GdkPixbuf *pixbuf, gint max_width, gint max_height)
 }
 
 static GdkPixbuf *
-_get_pixbuf_from_image_contents (const guchar *contents, gsize length, GError **out_error)
+_get_pixbuf_from_image_contents (const guchar *contents, gsize length, const gchar *filepath, GError **out_error)
 {
-  GdkPixbufLoader *pixbuf_loader = NULL;
+  g_autoptr(GdkPixbufLoader) pixbuf_loader = NULL;
   GdkPixbuf *pixbuf = NULL;
   GError *error = NULL;
 
@@ -360,6 +303,16 @@ _get_pixbuf_from_image_contents (const guchar *contents, gsize length, GError **
       pixbuf = gdk_pixbuf_loader_get_pixbuf (pixbuf_loader);
     }
 
+  /* Silly workaround to deal with what seems to be an obscure problem in
+   * GdkPixbufLoader. See https://bugzilla.gnome.org/show_bug.cgi?id=768639 */
+  if (error && filepath)
+    {
+      g_warning ("Not able to read image from %s: %s. Trying fallback...", filepath, error->message);
+      g_clear_error (&error);
+
+      pixbuf = gdk_pixbuf_new_from_file (filepath, &error);
+    }
+
   if (error)
     {
       DEBUG ("Error loading pixbuf: %s", error->message);
@@ -369,7 +322,6 @@ _get_pixbuf_from_image_contents (const guchar *contents, gsize length, GError **
   /* Keep the pixbuf before destroying the loader */
   if (pixbuf)
     g_object_ref (pixbuf);
-  g_object_unref (pixbuf_loader);
 
   return pixbuf;
 }
@@ -380,11 +332,11 @@ _get_pixbuf_from_image_contents (const guchar *contents, gsize length, GError **
 static GdkPixbuf *
 _get_pixbuf_from_video_file (GFile *file, GError **out_error)
 {
-#ifdef HAVE_GSTREAMER
+#if HAVE_GSTREAMER
   GdkPixbuf *pixbuf = NULL;
   GstElement *pipeline, *sink;
   GstStateChangeReturn ret;
-#ifdef HAVE_GSTREAMER_1_0
+#if HAVE_GSTREAMER_1_0
   GstStateChangeReturn sret;
 #else
   GstBuffer *buffer;
@@ -392,14 +344,14 @@ _get_pixbuf_from_video_file (GFile *file, GError **out_error)
   gint width, height;
   gboolean res;
 #endif
-  gchar *file_uri;
-  gchar *descr;
+  g_autofree gchar *file_uri = NULL;
+  g_autofree gchar *descr = NULL;
   gint64 duration, position;
   GError *error = NULL;
 
   /* create a new pipeline */
   file_uri = g_file_get_uri (file);
-#ifdef HAVE_GSTREAMER_1_0
+#if HAVE_GSTREAMER_1_0
   descr = g_strdup_printf ("uridecodebin uri=%s ! videoconvert ! videoscale "
                            " ! " CAPS " ! gdkpixbufsink name=sink", file_uri);
 #else
@@ -407,10 +359,7 @@ _get_pixbuf_from_video_file (GFile *file, GError **out_error)
                            " appsink name=sink caps=\"" CAPS "\"", file_uri);
 #endif
 
-  g_free (file_uri);
-
   pipeline = gst_parse_launch (descr, &error);
-  g_free (descr);
 
   if (error != NULL) {
     DEBUG ("Could not construct pipeline: %s\n", error->message);
@@ -446,7 +395,7 @@ _get_pixbuf_from_video_file (GFile *file, GError **out_error)
   }
 
   /* get the duration */
-#ifdef HAVE_GSTREAMER_1_0
+#if HAVE_GSTREAMER_1_0
   gst_element_query_duration (pipeline, GST_FORMAT_TIME, &duration);
 #else
   format = GST_FORMAT_TIME;
@@ -466,7 +415,7 @@ _get_pixbuf_from_video_file (GFile *file, GError **out_error)
   gst_element_seek_simple (pipeline, GST_FORMAT_TIME,
       GST_SEEK_FLAG_KEY_UNIT | GST_SEEK_FLAG_FLUSH, position);
 
-#ifdef HAVE_GSTREAMER_1_0
+#if HAVE_GSTREAMER_1_0
   sret = gst_element_get_state (pipeline, NULL, NULL, PREROLL_TIMEOUT);
   if (sret == GST_STATE_CHANGE_SUCCESS)
       g_object_get (sink, "last-pixbuf", &pixbuf, NULL);
@@ -540,11 +489,11 @@ frogr_util_get_pixbuf_for_video_file (GFile *file, gint max_width, gint max_heig
 }
 
 GdkPixbuf *
-frogr_util_get_pixbuf_from_image_contents (const guchar *contents, gsize length, gint max_width, gint max_height, GError **error)
+frogr_util_get_pixbuf_from_image_contents (const guchar *contents, gsize length, gint max_width, gint max_height, const gchar *filepath, GError **error)
 {
   GdkPixbuf *pixbuf = NULL;
 
-  pixbuf = _get_pixbuf_from_image_contents (contents, length, error);
+  pixbuf = _get_pixbuf_from_image_contents (contents, length, filepath, error);
   if (pixbuf)
     {
       GdkPixbuf *c_pixbuf = NULL;
@@ -563,8 +512,8 @@ frogr_util_get_datasize_string (gulong datasize)
 
   if (datasize != G_MAXULONG)
     {
+      g_autofree gchar *unit_str = NULL;
       gfloat datasize_float = G_MAXFLOAT;
-      gchar *unit_str = NULL;
       int n_divisions = 0;
 
       datasize_float = datasize;
@@ -590,10 +539,7 @@ frogr_util_get_datasize_string (gulong datasize)
         }
 
       if (unit_str)
-        {
-          result = g_strdup_printf ("%.1f %s", datasize_float, unit_str);
-          g_free (unit_str);
-        }
+        result = g_strdup_printf ("%.1f %s", datasize_float, unit_str);
     }
 
   return result;
@@ -608,7 +554,7 @@ frogr_util_get_supported_mimetypes (void)
     "image/png",
     "image/bmp",
     "image/gif",
-#ifdef HAVE_GSTREAMER
+#if HAVE_GSTREAMER
     "video/mpeg",
     "video/mp4",
     "video/quicktime",
